@@ -1,24 +1,27 @@
 # --------------------------------------------------------------------------------------------------
 # Copyright (c) Lukas Vik. All rights reserved.
 #
-# This file is part of the hdl_registers project.
+# This file is part of the hdl_registers project, a HDL register generator fast enough to be run
+# in real time.
 # https://hdl-registers.com
-# https://gitlab.com/tsfpga/hdl_registers
+# https://gitlab.com/hdl_registers/hdl_registers
 # --------------------------------------------------------------------------------------------------
 
+# Standard libraries
 import copy
-import hashlib
 import datetime
+import hashlib
 import re
+from pathlib import Path
 from shutil import copy2
 
-from pathlib import Path
-
+# Third party libraries
 from tsfpga import DEFAULT_FILE_ENCODING
-from tsfpga.git_utils import git_commands_are_available, get_git_commit
-from tsfpga.svn_utils import svn_commands_are_available, get_svn_revision_information
+from tsfpga.git_utils import get_git_commit, git_commands_are_available
+from tsfpga.svn_utils import get_svn_revision_information, svn_commands_are_available
 from tsfpga.system_utils import create_directory, create_file, read_file
 
+# Local folder libraries
 from . import __version__
 from .constant import Constant
 from .register import Register
@@ -154,9 +157,9 @@ class RegisterList:
 
         Arguments:
             register_name (str): The name of the register.
-            register_array_name (str): If the register is within a register array the name
+            register_array_name (str): If the register is within a register array, the name
                 of the array must be specified.
-            register_array_name (str): If the register is within a register array the array
+            register_array_name (str): If the register is within a register array, the array
                 iteration index must be specified.
 
         Return:
@@ -183,12 +186,12 @@ class RegisterList:
 
         Arguments:
             name (str): The name of the constant.
-            length (int): The constant value (signed).
+            value (bool, int, str): The constant value.
             description (str): Textual description for the constant.
         Return:
             Constant: The constant object that was created.
         """
-        constant = Constant(name, value, description)
+        constant = Constant(name=name, value=value, description=description)
         self.constants.append(constant)
         return constant
 
